"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.fileFromPath = exports.toFile = exports.UnprocessableEntityError = exports.PermissionDeniedError = exports.InternalServerError = exports.AuthenticationError = exports.BadRequestError = exports.RateLimitError = exports.ConflictError = exports.NotFoundError = exports.APIUserAbortError = exports.APIConnectionTimeoutError = exports.APIConnectionError = exports.APIError = exports.MiddayError = exports.Midday = void 0;
const Errors = __importStar(require("./error.js"));
const Uploads = __importStar(require("./uploads.js"));
const Core = __importStar(require("./core.js"));
const API = __importStar(require("./resources/index.js"));
const environments = {
    production: 'https://engine.midday.ai',
    staging: 'https://engine-staging.midday.ai',
    development: 'http://localhost:3002',
};
/**
 * API Client for interfacing with the Midday API.
 */
class Midday extends Core.APIClient {
    /**
     * API Client for interfacing with the Midday API.
     *
     * @param {string | undefined} [opts.bearerToken=process.env['MIDDAY_ENGINE_API_KEY'] ?? undefined]
     * @param {Environment} [opts.environment=production] - Specifies the environment URL to use for the API.
     * @param {string} [opts.baseURL=process.env['MIDDAY_BASE_URL'] ?? https://engine.midday.ai] - Override the default base URL for the API.
     * @param {number} [opts.timeout=1 minute] - The maximum amount of time (in milliseconds) the client will wait for a response before timing out.
     * @param {number} [opts.httpAgent] - An HTTP agent used to manage HTTP(s) connections.
     * @param {Core.Fetch} [opts.fetch] - Specify a custom `fetch` function implementation.
     * @param {number} [opts.maxRetries=2] - The maximum number of times the client will retry a request.
     * @param {Core.Headers} opts.defaultHeaders - Default headers to include with every request to the API.
     * @param {Core.DefaultQuery} opts.defaultQuery - Default query parameters to include with every request to the API.
     */
    constructor({ baseURL = Core.readEnv('MIDDAY_BASE_URL'), bearerToken = Core.readEnv('MIDDAY_ENGINE_API_KEY'), ...opts } = {}) {
        if (bearerToken === undefined) {
            throw new Errors.MiddayError("The MIDDAY_ENGINE_API_KEY environment variable is missing or empty; either provide it, or instantiate the Midday client with an bearerToken option, like new Midday({ bearerToken: 'My Bearer Token' }).");
        }
        const options = {
            bearerToken,
            ...opts,
            baseURL,
            environment: opts.environment ?? 'production',
        };
        if (baseURL && opts.environment) {
            throw new Errors.MiddayError('Ambiguous URL; The `baseURL` option (or MIDDAY_BASE_URL env var) and the `environment` option are given. If you want to use the environment you must pass baseURL: null');
        }
        super({
            baseURL: options.baseURL || environments[options.environment || 'production'],
            timeout: options.timeout ?? 60000 /* 1 minute */,
            httpAgent: options.httpAgent,
            maxRetries: options.maxRetries,
            fetch: options.fetch,
        });
        this.transactions = new API.Transactions(this);
        this.accounts = new API.Accounts(this);
        this.institutions = new API.Institutions(this);
        this.auth = new API.Auth(this);
        this.health = new API.Health(this);
        this.rates = new API.Rates(this);
        this._options = options;
        this.bearerToken = bearerToken;
    }
    defaultQuery() {
        return this._options.defaultQuery;
    }
    defaultHeaders(opts) {
        return {
            ...super.defaultHeaders(opts),
            ...this._options.defaultHeaders,
        };
    }
    authHeaders(opts) {
        return { Authorization: `Bearer ${this.bearerToken}` };
    }
}
exports.Midday = Midday;
_a = Midday;
Midday.Midday = _a;
Midday.DEFAULT_TIMEOUT = 60000; // 1 minute
Midday.MiddayError = Errors.MiddayError;
Midday.APIError = Errors.APIError;
Midday.APIConnectionError = Errors.APIConnectionError;
Midday.APIConnectionTimeoutError = Errors.APIConnectionTimeoutError;
Midday.APIUserAbortError = Errors.APIUserAbortError;
Midday.NotFoundError = Errors.NotFoundError;
Midday.ConflictError = Errors.ConflictError;
Midday.RateLimitError = Errors.RateLimitError;
Midday.BadRequestError = Errors.BadRequestError;
Midday.AuthenticationError = Errors.AuthenticationError;
Midday.InternalServerError = Errors.InternalServerError;
Midday.PermissionDeniedError = Errors.PermissionDeniedError;
Midday.UnprocessableEntityError = Errors.UnprocessableEntityError;
Midday.toFile = Uploads.toFile;
Midday.fileFromPath = Uploads.fileFromPath;
exports.MiddayError = Errors.MiddayError, exports.APIError = Errors.APIError, exports.APIConnectionError = Errors.APIConnectionError, exports.APIConnectionTimeoutError = Errors.APIConnectionTimeoutError, exports.APIUserAbortError = Errors.APIUserAbortError, exports.NotFoundError = Errors.NotFoundError, exports.ConflictError = Errors.ConflictError, exports.RateLimitError = Errors.RateLimitError, exports.BadRequestError = Errors.BadRequestError, exports.AuthenticationError = Errors.AuthenticationError, exports.InternalServerError = Errors.InternalServerError, exports.PermissionDeniedError = Errors.PermissionDeniedError, exports.UnprocessableEntityError = Errors.UnprocessableEntityError;
exports.toFile = Uploads.toFile;
exports.fileFromPath = Uploads.fileFromPath;
(function (Midday) {
    Midday.Transactions = API.Transactions;
    Midday.Accounts = API.Accounts;
    Midday.Institutions = API.Institutions;
    Midday.Auth = API.Auth;
    Midday.Health = API.Health;
    Midday.Rates = API.Rates;
})(Midday = exports.Midday || (exports.Midday = {}));
exports = module.exports = Midday;
exports.default = Midday;
//# sourceMappingURL=index.js.map