// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
var _a;
import * as Errors from "./error.mjs";
import * as Uploads from "./uploads.mjs";
import * as Core from "./core.mjs";
import * as API from "./resources/index.mjs";
const environments = {
    production: 'https://engine.midday.ai',
    staging: 'https://engine-staging.midday.ai',
    development: 'http://localhost:3002',
};
/**
 * API Client for interfacing with the Midday API.
 */
export class Midday extends Core.APIClient {
    /**
     * API Client for interfacing with the Midday API.
     *
     * @param {string | undefined} [opts.bearerToken=process.env['MIDDAY_ENGINE_API_KEY'] ?? undefined]
     * @param {Environment} [opts.environment=production] - Specifies the environment URL to use for the API.
     * @param {string} [opts.baseURL=process.env['MIDDAY_BASE_URL'] ?? https://engine.midday.ai] - Override the default base URL for the API.
     * @param {number} [opts.timeout=1 minute] - The maximum amount of time (in milliseconds) the client will wait for a response before timing out.
     * @param {number} [opts.httpAgent] - An HTTP agent used to manage HTTP(s) connections.
     * @param {Core.Fetch} [opts.fetch] - Specify a custom `fetch` function implementation.
     * @param {number} [opts.maxRetries=2] - The maximum number of times the client will retry a request.
     * @param {Core.Headers} opts.defaultHeaders - Default headers to include with every request to the API.
     * @param {Core.DefaultQuery} opts.defaultQuery - Default query parameters to include with every request to the API.
     */
    constructor({ baseURL = Core.readEnv('MIDDAY_BASE_URL'), bearerToken = Core.readEnv('MIDDAY_ENGINE_API_KEY'), ...opts } = {}) {
        if (bearerToken === undefined) {
            throw new Errors.MiddayError("The MIDDAY_ENGINE_API_KEY environment variable is missing or empty; either provide it, or instantiate the Midday client with an bearerToken option, like new Midday({ bearerToken: 'My Bearer Token' }).");
        }
        const options = {
            bearerToken,
            ...opts,
            baseURL,
            environment: opts.environment ?? 'production',
        };
        if (baseURL && opts.environment) {
            throw new Errors.MiddayError('Ambiguous URL; The `baseURL` option (or MIDDAY_BASE_URL env var) and the `environment` option are given. If you want to use the environment you must pass baseURL: null');
        }
        super({
            baseURL: options.baseURL || environments[options.environment || 'production'],
            timeout: options.timeout ?? 60000 /* 1 minute */,
            httpAgent: options.httpAgent,
            maxRetries: options.maxRetries,
            fetch: options.fetch,
        });
        this.transactions = new API.Transactions(this);
        this.accounts = new API.Accounts(this);
        this.institutions = new API.Institutions(this);
        this.auth = new API.Auth(this);
        this.health = new API.Health(this);
        this.rates = new API.Rates(this);
        this._options = options;
        this.bearerToken = bearerToken;
    }
    defaultQuery() {
        return this._options.defaultQuery;
    }
    defaultHeaders(opts) {
        return {
            ...super.defaultHeaders(opts),
            ...this._options.defaultHeaders,
        };
    }
    authHeaders(opts) {
        return { Authorization: `Bearer ${this.bearerToken}` };
    }
}
_a = Midday;
Midday.Midday = _a;
Midday.DEFAULT_TIMEOUT = 60000; // 1 minute
Midday.MiddayError = Errors.MiddayError;
Midday.APIError = Errors.APIError;
Midday.APIConnectionError = Errors.APIConnectionError;
Midday.APIConnectionTimeoutError = Errors.APIConnectionTimeoutError;
Midday.APIUserAbortError = Errors.APIUserAbortError;
Midday.NotFoundError = Errors.NotFoundError;
Midday.ConflictError = Errors.ConflictError;
Midday.RateLimitError = Errors.RateLimitError;
Midday.BadRequestError = Errors.BadRequestError;
Midday.AuthenticationError = Errors.AuthenticationError;
Midday.InternalServerError = Errors.InternalServerError;
Midday.PermissionDeniedError = Errors.PermissionDeniedError;
Midday.UnprocessableEntityError = Errors.UnprocessableEntityError;
Midday.toFile = Uploads.toFile;
Midday.fileFromPath = Uploads.fileFromPath;
export const { MiddayError, APIError, APIConnectionError, APIConnectionTimeoutError, APIUserAbortError, NotFoundError, ConflictError, RateLimitError, BadRequestError, AuthenticationError, InternalServerError, PermissionDeniedError, UnprocessableEntityError, } = Errors;
export var toFile = Uploads.toFile;
export var fileFromPath = Uploads.fileFromPath;
(function (Midday) {
    Midday.Transactions = API.Transactions;
    Midday.Accounts = API.Accounts;
    Midday.Institutions = API.Institutions;
    Midday.Auth = API.Auth;
    Midday.Health = API.Health;
    Midday.Rates = API.Rates;
})(Midday || (Midday = {}));
export default Midday;
//# sourceMappingURL=index.mjs.map