import { APIResource } from "../resource.js";
import * as Core from "../core.js";
import * as AccountsAPI from "./accounts.js";
import * as UsageAPI from "./institutions/usage.js";
export declare class Accounts extends APIResource {
    /**
     * Get Accounts
     */
    list(query: AccountListParams, options?: Core.RequestOptions): Core.APIPromise<Accounts>;
    /**
     * Delete Accounts
     */
    delete(params: AccountDeleteParams, options?: Core.RequestOptions): Core.APIPromise<AccountDeleteResponse>;
    /**
     * Get Account Balance
     */
    balance(query: AccountBalanceParams, options?: Core.RequestOptions): Core.APIPromise<AccountBalance>;
}
export interface AccountBalance {
    data: AccountBalance.Data | null;
}
export declare namespace AccountBalance {
    interface Data {
        amount: number;
        currency: string;
    }
}
export interface Accounts {
    data: Array<Accounts.Data>;
}
export declare namespace Accounts {
    interface Data {
        id: string;
        balance: Data.Balance;
        currency: string;
        enrollment_id: string | null;
        institution: UsageAPI.Institution;
        name: string;
        type: 'depository' | 'credit' | 'other_asset' | 'loan' | 'other_liability';
    }
    namespace Data {
        interface Balance {
            amount: number;
            currency: string;
        }
    }
}
export interface AccountDeleteResponse {
    success: boolean;
}
export interface AccountListParams {
    provider: 'teller' | 'plaid' | 'gocardless';
    /**
     * GoCardLess reference id
     */
    id?: string;
    /**
     * Teller & Plaid access token
     */
    accessToken?: string;
    /**
     * Plaid institution id
     */
    institutionId?: string;
}
export interface AccountDeleteParams {
    /**
     * Account id (GoCardLess)
     */
    accountId: string;
    provider: 'teller' | 'plaid' | 'gocardless';
    /**
     * Teller & Plaid access token
     */
    accessToken?: string;
}
export interface AccountBalanceParams {
    /**
     * Account id
     */
    id: string;
    provider: 'teller' | 'plaid' | 'gocardless';
    /**
     * Teller & Plaid access token
     */
    accessToken?: string;
}
export declare namespace Accounts {
    export import AccountBalance = AccountsAPI.AccountBalance;
    export import Accounts = AccountsAPI.Accounts;
    export import AccountDeleteResponse = AccountsAPI.AccountDeleteResponse;
    export import AccountListParams = AccountsAPI.AccountListParams;
    export import AccountDeleteParams = AccountsAPI.AccountDeleteParams;
    export import AccountBalanceParams = AccountsAPI.AccountBalanceParams;
}
//# sourceMappingURL=accounts.d.ts.map