import { APIResource } from "../resource.js";
import * as Core from "../core.js";
import * as TransactionsAPI from "./transactions.js";
export declare class Transactions extends APIResource {
    /**
     * Get transactions
     */
    list(query: TransactionListParams, options?: Core.RequestOptions): Core.APIPromise<Transactions>;
}
export interface Transactions {
    data: Array<Transactions.Data>;
}
export declare namespace Transactions {
    interface Data {
        id: string;
        amount: number;
        balance: number | null;
        category: string | null;
        currency: string;
        date: string;
        description: string | null;
        method: string | null;
        name: string;
        status: 'pending' | 'posted';
    }
}
export interface TransactionListParams {
    /**
     * Get transactions by accountId
     */
    accountId: string;
    /**
     * Get transactions with the correct amount depending on credit or depository
     */
    accountType: 'credit' | 'depository';
    provider: 'teller' | 'plaid' | 'gocardless';
    /**
     * Used for Teller and Plaid
     */
    accessToken?: string;
    /**
     * Get latest transactions
     */
    latest?: 'true' | 'false';
}
export declare namespace Transactions {
    export import Transactions = TransactionsAPI.Transactions;
    export import TransactionListParams = TransactionsAPI.TransactionListParams;
}
//# sourceMappingURL=transactions.d.ts.map